==> humhub-1.8.0-beta.1.tar.gz: humhub-1.8.0-beta.1/protected/humhub/messages/hu/base.php <==
<?php
return array (
  '<strong>Confirm</strong> Action' => 'Művelet<strong>megerősítése</strong>',
  '<strong>Latest</strong> updates' => '<strong>Legújabb</strong> frissítések',
  '<strong>Mail</strong> summary' => '<strong>Üzenetek</strong> összesítő',
  'Account settings' => 'Fiók beállítások',
  'Actions' => 'Műveletek',
  'Add:' => 'Hozzáadás:',
  'Administration' => 'Adminisztráció',
  'All' => 'Minden',
  'Allow' => 'Engedélyezés',
  'An error occurred while handling your last action. (Handler not found).' => 'Egy hiba merült fel a legutóbbi művelet elvégzésekor. (Handler nem található)',
  'An unexpected error occurred while loading the search result.' => 'Váratlan hiba merült fel a keresés eredményeinek betöltése közben.',
  'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Váratlan hiba merült fel. Ha továbbra is hiba lépne fel, keresd az oldal egyik adminisztrátorát.',
  'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Váratlan szerverhiba történt. Ha továbbra is hiba lépne fel, keresd az oldal egyik adminisztrátorát.',
  'An unknown error occurred while uploading.' => 'Ismeretlen hiba történt feltöltés közben.',
  'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Hiba történt a feltöltés közben, lehetséges, hogy túl nagy a fájlméret! Tipp: ellenőrizd a upload_max_filesize és a post_max_size php beállításokat.',
  'Back' => 'Vissza',
  'Back to dashboard' => 'Vissza az áttekintéshez',
  'Cancel' => 'Mégsem',
  'Choose language:' => 'Válassz nyelvet:',
  'Close' => 'Bezár',
  'Collapse' => 'Összecsukás',
  'Confirm' => 'Rendben',
  'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'A tartalom bővítmény forrásának HActiveRecordContent vagy  HActiveRecordContentAddon példánynak kell lennie!',
  'Copy to clipboard' => 'Másolás vágólapra',
  'Could not find content of addon!' => 'Nem található a bővítmény tartalma!',
  'Could not find requested page.' => 'Nem található a kért oldal!',
  'Database connection time: {dbTime} - Configured time zone: {time}' => 'Adatbázis kapcsolat ideje: {dbTime} - Beállított időzóna: {time}',
  'Default' => 'Alapértelmezett',
  'Delete' => 'Törlés',
  'Deny' => 'Tiltás',
  'Do you really want to perform this action?' => 'Biztos, hogy végrehajtod a műveletet?',
  'Edit' => 'Szerkesztés',
  'Error' => 'Hiba',
  'Error while running your last action (Invalid request method).' => 'Hiba történt a művelet közben.
(Érvénytelen kérelem)',
  'Error:' => 'Hiba:',
  'Expand' => 'Kinyit',
  'Export' => 'Exportálás',
  'Info:' => 'Információ:',
  'Invalid request method!' => 'Érvénytelen kérelem!',
  'It looks like you may have taken the wrong turn.' => 'Hoppá... Valami hiba történt.',
  'Language' => 'Nyelv:',
  'Loading...' => 'Betöltés...',
  'Login' => 'Bejelentkezés',
  'Logo of {appName}' => '{appName} logója',
  'Logout' => 'Kijelentkezés',
  'Menu' => 'Menü',
  'Module is not enabled on this content container!' => 'A modul nincs engedélyezve a tartalom tárolójában.',
  'My profile' => 'Profilom',
  'New profile image' => 'Új profilkép',
  'Next' => 'Következő',
  'No error information given.' => 'Nincs hibainformáció.',
  'Oooops...' => 'Hoppá...',
  'Open' => 'Megnyitás',
  'Please type at least 3 characters' => 'Gépelj be legalább 3 karaktert',
  'Please type at least {count} characters' => 'Legalább adj meg {count} karaktert',
  'Powered by {name}' => 'Powered by {name}',
  'Profile dropdown' => 'Profil legördülő menü',
  'Profile picture of {displayName}' => '{displayName} profilképe',
  'Save' => 'Mentés',
  'Saved' => 'Mentve',
  'Search' => 'Keresés',
  'Select Me' => 'Válassz ki',
  'Show less' => 'Kevesebb mutatása',
  'Show more' => 'Több mutatása',
  'Some files could not be uploaded:' => 'Néhány fájlt nem sikerült feltölteni:',
  'Text could not be copied to clipboard' => 'A szöveget nem sikerült a vágólapra másolni',
  'Text has been copied to clipboard' => 'A szöveg a vágolapra másolva',
  'The date has to be in the past.' => 'A dátumnak a múltban kell lennie.',
  'The file has been deleted.' => 'A fájlt törölve lett.',
  'The requested resource could not be found.' => 'A kért tartalom nem található.',
  'The space has been archived.' => 'A közösség archiválásra került.',
  'The space has been unarchived.' => 'Közösség archiválása megszüntetve.',
  'There are unsaved changes, do you really want to leave this page?' => 'Vannak nem mentett változtatások, valóban el akarja hagyni ezt az oldalt?',
  'Time Zone' => 'Időzóna',
  'Toggle comment menu' => 'Hozzászólások menü ki-bekapcsolása',
  'Toggle panel menu' => 'Panel menü ki-bekapcsolása',
  'Toggle post menu' => 'Bejegyzések menü ki-bekapcsolása',
  'Toggle stream entry menu' => 'A folyam menü ki-bekapcsolása',
  'Unsubscribe' => 'Leiratkozás',
  'Upload' => 'Feltöltés',
  'Upload file' => 'Fájl feltöltése',
  'You are not allowed to run this action.' => 'Nincs engedélyed, hogy ezt a műveletet végrehajsd.',
  '{nFormatted}B' => '{nFormatted}B',
  '{nFormatted}K' => '{nFormatted}K',
  '{nFormatted}M' => '{nFormatted}M',
);

==> humhub-1.15.0-beta.1.tar.gz: humhub-1.15.0-beta.1/protected/humhub/messages/hu/base.php <==
<?php
return array (
  '<strong>Confirm</strong> Action' => 'Művelet<strong>megerősítése</strong>',
  '<strong>Latest</strong> updates' => '<strong>Legújabb</strong> frissítések',
  '<strong>Mail</strong> summary' => '<strong>Üzenetek</strong> összesítő',
  'Actions' => 'Műveletek',
  'Add:' => 'Hozzáadás:',
  'Administration' => 'Adminisztráció',
  'All' => 'Minden',
  'Allow' => 'Engedélyezés',
  'Allow content from external source' => 'Külső forrásból származó tartalom engedélyezése',
  'Always allow content from this provider!' => 'Mindig engedélyezze a tartalmat ettől a szolgáltatótól!',
  'An error occurred while handling your last action. (Handler not found).' => 'Egy hiba merült fel a legutóbbi művelet elvégzésekor. (Handler nem található)',
  'An unexpected error occurred while loading the search result.' => 'Váratlan hiba merült fel a keresés eredményeinek betöltése közben.',
  'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Váratlan hiba merült fel. Ha továbbra is hiba lépne fel, keresd az oldal egyik adminisztrátorát.',
  'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => 'Váratlan hiba történt. Kérjük, ellenőrizze, hogy a fájl meghaladja-e a megengedett {maxUploadSize} feltöltési korlátot.',
  'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Váratlan szerverhiba történt. Ha továbbra is hiba lépne fel, keresd az oldal egyik adminisztrátorát.',
  'Back' => 'Vissza',
  'Back to dashboard' => 'Vissza az áttekintéshez',
  'Cancel' => 'Mégsem',
  'Choose language:' => 'Válassz nyelvet:',
  'Close' => 'Bezár',
  'Collapse' => 'Összecsukás',
  'Confirm' => 'Rendben',
  'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'A tartalom bővítmény forrásának HActiveRecordContent vagy  HActiveRecordContentAddon példánynak kell lennie!',
  'Copy to clipboard' => 'Másolás vágólapra',
  'Could not find content of addon!' => 'Nem található a bővítmény tartalma!',
  'Could not find requested page.' => 'Nem található a kért oldal!',
  'Default' => 'Alapértelmezett',
  'Delete' => 'Törlés',
  'Deny' => 'Tiltás',
  'Do you really want to perform this action?' => 'Biztos, hogy végrehajtod a műveletet?',
  'Do you want to enable content from \'{urlPrefix}\'?' => 'Engedélyezi a tartalmat a következőről: \'{urlPrefix}\'?',
  'Edit' => 'Szerkesztés',
  'Error' => 'Hiba',
  'Error while running your last action (Invalid request method).' => 'Hiba történt a művelet közben.
(Érvénytelen kérelem)',
  'Error:' => 'Hiba:',
  'Expand' => 'Kinyit',
  'Export' => 'Exportálás',
  'Info:' => 'Információ:',
  'Invalid request method!' => 'Érvénytelen kérelem!',
  'It looks like you may have taken the wrong turn.' => 'Hoppá... Valami hiba történt.',
  'Language' => 'Nyelv:',
  'Loading...' => 'Betöltés...',
  'Login' => 'Bejelentkezés',
  'Logo of {appName}' => '{appName} logója',
  'Logout' => 'Kijelentkezés',
  'Menu' => 'Menü',
  'Module is not enabled on this content container!' => 'A modul nincs engedélyezve a tartalom tárolójában.',
  'My Profile' => 'A profilom',
  'New profile image' => 'Új profilkép',
  'Next' => 'Következő',
  'No error information given.' => 'Nincs hibainformáció.',
  'Oooops...' => 'Hoppá...',
  'Open' => 'Megnyitás',
  'Please type at least 3 characters' => 'Gépelj be legalább 3 karaktert',
  'Please type at least {count} characters' => 'Legalább adj meg {count} karaktert',
  'Powered by {name}' => 'Powered by {name}',
  'Profile dropdown' => 'Profil legördülő menü',
  'Profile picture of {displayName}' => '{displayName} profilképe',
  'Save' => 'Mentés',
  'Saved' => 'Mentve',
  'Search' => 'Keresés',
  'Search...' => 'Keresés...',
  'Select Me' => 'Válassz ki',
  'Settings' => 'Beállítások',
  'Show less' => 'Kevesebb mutatása',
  'Show more' => 'Több mutatása',
  'Some files could not be uploaded:' => 'Néhány fájlt nem sikerült feltölteni:',
  'Stop impersonation' => 'Hagyd abba a személyeskedést!',
  'Text could not be copied to clipboard' => 'A szöveget nem sikerült a vágólapra másolni',
  'Text has been copied to clipboard' => 'A szöveg a vágolapra másolva',
  'The date has to be in the past.' => 'A dátumnak a múltban kell lennie.',
  'The file has been deleted.' => 'A fájlt törölve lett.',
  'The requested resource could not be found.' => 'A kért tartalom nem található.',
  'The space has been archived.' => 'A közösség archiválásra került.',
  'The space has been unarchived.' => 'Közösség archiválása visszavonva.',
  'Time Zone' => 'Időzóna',
  'Toggle comment menu' => 'Hozzászólások menü engedélyezése',
  'Toggle panel menu' => 'Panel menü engedélyezése',
  'Toggle post menu' => 'Bejegyzések menü engedélyezése',
  'Toggle stream entry menu' => 'A hírfolyam menü engedélyezése',
  'Unsaved changes will be lost. Do you want to proceed?' => 'Vannak nem mentett változtatások, valóban el akarod hagyni ezt az oldalt?',
  'Unsubscribe' => 'Leiratkozás',
  'Upload' => 'Feltöltés',
  'Upload file' => 'Fájl feltöltése',
  'You are not allowed to run this action.' => 'Nincs engedélyed, hogy ezt a műveletet végrehajtsd.',
  'verify your upload_max_filesize and post_max_size php settings.' => 'ellenőrizze az upload_max_filesize és a post_max_size php beállításait.',
  '{nFormatted}B' => '{nFormatted}B',
  '{nFormatted}K' => '{nFormatted}K',
  '{nFormatted}M' => '{nFormatted}M',
);
